package com.muyu.config.cache;

import com.github.benmanes.caffeine.cache.Expiry;
import org.checkerframework.checker.index.qual.NonNegative;

import java.util.concurrent.TimeUnit;

/**
 * @Author: DongZeLiang
 * @date: 2024/9/12
 * @Description: 缓存过期
 * @Version: 1.0
 */
public class CacheExpiry implements Expiry<String, ExpiryTime> {
    /**
     * @param key 缓存键
     * @param value 缓存值
     * @param currentTime 当前时间戳
     *
     * @return 进入有效期前的时间长度，以纳秒为单位
     */
    @Override
    public long expireAfterCreate (String key, ExpiryTime value, long currentTime) {
        return TimeUnit.SECONDS.toNanos(value.getExpiryTime());
    }

    /**
     * @param key 缓存键
     * @param value 缓存值
     * @param currentTime 当前时间戳
     * @param currentDuration 剩余时间
     *
     * @return 进入有效期前的时间长度，以纳秒为单位
     */
    @Override
    public long expireAfterUpdate (String key, ExpiryTime value, long currentTime, @NonNegative long currentDuration) {
        return TimeUnit.SECONDS.toNanos(value.getRefreshTime());
    }

    /**
     * @param key 缓存键
     * @param value 缓存值
     * @param currentTime 当前时间戳
     * @param currentDuration 剩余持续时间
     *
     * @return 进入有效期前的时间长度，以纳秒为单位
     */
    @Override
    public long expireAfterRead (String key, ExpiryTime value, long currentTime, @NonNegative long currentDuration) {
        return TimeUnit.SECONDS.toNanos(value.getRefreshTime());
    }
}
