package com.muyu.web.common;

import lombok.Data;

import java.io.Serializable;

/**
 * 响应信息主体
 *
 * @author ruoyi
 */
@Data
public class Result<T> implements Serializable {
    /**
     * 成功
     */
    public static final int SUCCESS = HttpStatus.SUCCESS;
    /**
     * 失败
     */
    public static final int FAIL = HttpStatus.ERROR;
    private static final long serialVersionUID = 1L;
    /**
     * 系统警告消息
     */
    private static final int WARN = HttpStatus.WARN;

    private int code;

    private String msg;

    private T data;

    public static <T> Result<T> success () {
        return restResult(null, SUCCESS, "操作成功");
    }

    public static <T> Result<T> success (T data) {
        return restResult(data, SUCCESS, "操作成功");
    }

    public static <T> Result<T> success (T data, String msg) {
        return restResult(data, SUCCESS, msg);
    }

    public static <T> Result<T> error () {
        return restResult(null, FAIL, "操作失败");
    }

    public static <T> Result<T> error (String msg) {
        return restResult(null, FAIL, msg);
    }

    public static <T> Result<T> error (T data) {
        return restResult(data, FAIL, "操作失败");
    }

    public static <T> Result<T> error (T data, String msg) {
        return restResult(data, FAIL, msg);
    }

    public static <T> Result<T> error (int code, String msg) {
        return restResult(null, code, msg);
    }

    public static <T> Result<T> warn () {
        return restResult(null, WARN, "操作失败");
    }

    public static <T> Result<T> warn (String msg) {
        return restResult(null, WARN, msg);
    }

    public static <T> Result<T> warn (T data) {
        return restResult(data, WARN, "操作失败");
    }

    public static <T> Result<T> warn (T data, String msg) {
        return restResult(data, WARN, msg);
    }

    public static <T> Result<T> warn (int code, String msg) {
        return restResult(null, code, msg);
    }

    private static <T> Result<T> restResult (T data, int code, String msg) {
        Result<T> apiResult = new Result<>();
        apiResult.setCode(code);
        apiResult.setData(data);
        apiResult.setMsg(msg);
        return apiResult;
    }

    public static <T> Boolean isError (Result<T> ret) {
        return !isSuccess(ret);
    }

    public static <T> Boolean isSuccess (Result<T> ret) {
        return Result.SUCCESS == ret.getCode();
    }
}
