package com.muyu.web.controller;

import com.muyu.system.domain.LoginUserInfo;
import com.muyu.web.common.Result;
import com.muyu.web.domain.req.UserLoginReq;
import com.muyu.web.domain.req.UserRegReq;
import com.muyu.web.service.SystemAuthService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @Author: DongZeLiang
 * @date: 2024/9/12
 * @Description: 系统登录接口
 * @Version: 1.0
 */
@RestController
@RequestMapping("/system/auth")
public class SystemAuthController {

    @Autowired
    private SystemAuthService systemAuthService;

    @PostMapping("/reg")
    public Result<String> reg(@RequestBody @Validated UserRegReq userRegReq) {
        systemAuthService.reg(userRegReq);
        return Result.success();
    }

    /**
     * 用户登录
     * @param userLoginReq 用户登录请求对象
     * @return token
     */
    @PostMapping("/login")
    public Result<String> login(@RequestBody @Validated UserLoginReq userLoginReq){
        String token = systemAuthService.login(userLoginReq.getUserName(), userLoginReq.getPassword());
        return Result.success(token);
    }

    /**
     * 用户退出
     * @return token
     */
    @GetMapping("/info")
    public Result<LoginUserInfo> info(){
        return Result.success(systemAuthService.info());
    }

    /**
     * 用户退出
     * @return token
     */
    @PostMapping("/logout")
    public Result<String> logout(){
        systemAuthService.logout();
        return Result.success();
    }
}
