package com.muyu.web.domain.model;

import com.muyu.system.properties.ServerConfigProperties;
import com.muyu.web.domain.ServerConfig;
import com.muyu.web.domain.req.ServerConfigEditReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Author: DongZeLiang
 * @date: 2024/6/10
 * @Description: 服务器配置业务模型
 * @Version: 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ServerConfigModel {

    /**
     * 主机地址
     */
    private String host;
    /**
     * 端口号
     */
    private String port;
    /**
     * 负载地址
     */
    private String uri;
    /**
     * 默认MQTT地址
     */
    private String defaultMqttAddr;
    /**
     * 默认MQTT主题
     */
    private String defaultMqttTopic;
    /**
     * 默认MQTT交付级别
     */
    private Integer defaultMqttQos;

    public static ServerConfigModel serverConfigBuild (ServerConfig serverConfig) {
        return builder()
                .host(serverConfig.getHost().trim())
                .port(serverConfig.getPort())
                .uri(serverConfig.getUri().trim())
                .defaultMqttAddr(serverConfig.getDefaultMqttAddr().trim())
                .defaultMqttTopic(serverConfig.getDefaultMqttTopic().trim())
                .defaultMqttQos(serverConfig.getDefaultMqttQos())
                .build();
    }

    public static ServerConfigModel editReqBuild (ServerConfigEditReq serverConfigReq) {
        return builder()
                .host(serverConfigReq.getHost().trim())
                .port(serverConfigReq.getPort())
                .uri(serverConfigReq.getUri().trim())
                .defaultMqttAddr(serverConfigReq.getDefaultMqttAddr().trim())
                .defaultMqttTopic(serverConfigReq.getDefaultMqttTopic().trim())
                .defaultMqttQos(serverConfigReq.getDefaultMqttQos())
                .build();
    }

    public static ServerConfigModel serverConfigPropertiesBuild (ServerConfigProperties serverConfigProperties) {
        return builder()
                .host(serverConfigProperties.getHost().trim())
                .port(serverConfigProperties.getPort())
                .uri(serverConfigProperties.getUri().trim())
                .defaultMqttAddr(serverConfigProperties.getMqttAddr().trim())
                .defaultMqttTopic(serverConfigProperties.getMqttTopic().trim())
                .defaultMqttQos(serverConfigProperties.getMqttQos())
                .build();
    }
}
