package com.muyu.web.service.impl;

import com.muyu.vehicle.VehicleInstance;
import com.muyu.vehicle.core.LocalContainer;
import com.muyu.web.domain.model.OverviewModel;
import com.muyu.web.service.OverviewService;
import org.springframework.stereotype.Service;

import java.util.Collection;

/**
 * @Author: DongZeLiang
 * @date: 2024/6/10
 * @Description: 车辆概述业务实现层
 * @Version: 1.0
 */
@Service
public class OverviewServiceImpl implements OverviewService {

    /**
     * 车辆模拟概述
     *
     * @return 概述数据模型
     */
    @Override
    public OverviewModel overview () {
        // 车辆实例对象
        Collection<VehicleInstance> instanceList = LocalContainer.getTenantVehicleDataMap().values();


        return OverviewModel.builder()
                .online(
                        instanceList.stream()
                                .filter(VehicleInstance::isOnline)
                                .filter(VehicleInstance::isSend)
                                .count()
                )
                .offline(
                        instanceList.stream()
                                .filter(vehicleInstance -> !vehicleInstance.isOnline())
                                .count()
                )
                .pause(
                        instanceList.stream()
                                .filter(VehicleInstance::isOnline)
                                .filter(vehicleInstance -> !vehicleInstance.isSend())
                                .count()
                )
                .build();
    }
}
